# Installation

Code Video Generator is a library for [Manim](https://github.com/manimcommunity/manim), and as such, the first
 step is to follow their [installation buide](https://docs.manim.community/en/latest/installation.html).
 
Once Manim is installed, you can simply install code-video-generator using pip:

```
pip install code-video-generator
```

Note: You may need to install manimmc from source in order to get the [comment bug fix](https://github.com/ManimCommunity/manim/issues/638). 